ExtensionIdExtractor

Struct ExtensionIdExtractor 

pub struct ExtensionIdExtractor<T> { /* private fields */ }
Extract ID from a request extension.

This extractor looks for an ID that was set by a previous middleware (e.g., an authentication middleware) as a request extension.

Example

use axum_acl::ExtensionIdExtractor;

// The authentication middleware should insert a User struct into extensions
#[derive(Clone)]
struct AuthenticatedUser {
    id: String,
    name: String,
}

let extractor = ExtensionIdExtractor::<AuthenticatedUser>::new(|user| user.id.clone());

Implementations

Source

impl<T> ExtensionIdExtractor<T>

pub fn new<F>(extract_fn: F) -> Self
where F: Fn(&T) -> String + Send + Sync + 'static,

Create a new extension ID extractor.

The extract_fn converts the extension type to an ID string.