pub struct ExtensionRoleExtractor<T> { /* private fields */ }Expand description
Extract roles from a request extension.
This extractor looks for roles that were set by a previous middleware (e.g., an authentication middleware) as a request extension.
Example
use axum_acl::ExtensionRoleExtractor;
// The authentication middleware should insert a Roles struct into extensions
#[derive(Clone)]
struct UserRoles(u32);
let extractor = ExtensionRoleExtractor::<UserRoles>::new(|roles| roles.0);Implementations