pub struct HeaderRoleExtractor { /* private fields */ }Expand description
Extract roles bitmask from an HTTP header.
The header value is parsed as a u32 bitmask directly, or you can use a custom parser function to convert header values to bitmasks.
Example
use axum_acl::HeaderRoleExtractor;
// Extract roles bitmask directly from X-Roles header (as decimal or hex)
let extractor = HeaderRoleExtractor::new("X-Roles");
// With a custom default roles bitmask for missing headers
let extractor = HeaderRoleExtractor::new("X-Roles")
.with_default_roles(0b100); // guest roleImplementations